EXPORTS
	??0CMsgMailAppUi@@QAE@XZ @ 1 NONAME ; CMsgMailAppUi::CMsgMailAppUi(void)
	??0CMsgMailDocument@@IAE@AAVCEikApplication@@@Z @ 2 NONAME ; CMsgMailDocument::CMsgMailDocument(class CEikApplication &)
	??0CMsgMailPreferences@@QAE@XZ @ 3 NONAME ; CMsgMailPreferences::CMsgMailPreferences(void)
	??1CMailCRHandler@@UAE@XZ @ 4 NONAME ; CMailCRHandler::~CMailCRHandler(void)
	??1CMsgMailAppUi@@UAE@XZ @ 5 NONAME ; CMsgMailAppUi::~CMsgMailAppUi(void)
	??1CMsgMailDocument@@UAE@XZ @ 6 NONAME ; CMsgMailDocument::~CMsgMailDocument(void)
	??1MsgMailDRMHandler@@UAE@XZ @ 7 NONAME ; MsgMailDRMHandler::~MsgMailDRMHandler(void)
	?AttachmentManager@CMailMessage@@QBEAAVMMsvAttachmentManager@@XZ @ 8 NONAME ; class MMsvAttachmentManager & CMailMessage::AttachmentManager(void) const
	?CharsetIdL@CMailMessage@@QAEIXZ @ 9 NONAME ; unsigned int CMailMessage::CharsetIdL(void)
	?CheckFFSL@CMsgMailAppUi@@QAEHH@Z @ 10 NONAME ; int CMsgMailAppUi::CheckFFSL(int)
	?CheckIfBannedL@CMsgMailAppUi@@IAEHAAVRFile@@@Z @ 11 NONAME ; int CMsgMailAppUi::CheckIfBannedL(class RFile &)
	?CheckIfBannedL@CMsgMailAppUi@@IAEHABVTDesC16@@@Z @ 12 NONAME ; int CMsgMailAppUi::CheckIfBannedL(class TDesC16 const &)
	?CleanupWaitDialog@CMsgMailAppUi@@KAXPAX@Z @ 13 NONAME ; void CMsgMailAppUi::CleanupWaitDialog(void *)
	?CleanupWaitNoteWrapper@CMsgMailAppUi@@KAXPAX@Z @ 14 NONAME ; void CMsgMailAppUi::CleanupWaitNoteWrapper(void *)
	?ConfirmationNoteL@MailUtils@@SAXABVTDesC16@@@Z @ 15 NONAME ; void MailUtils::ConfirmationNoteL(class TDesC16 const &)
	?ConfirmationNoteL@MailUtils@@SAXH@Z @ 16 NONAME ; void MailUtils::ConfirmationNoteL(int)
	?ConfirmationQueryL@MailUtils@@SAHABVTDesC16@@@Z @ 17 NONAME ; int MailUtils::ConfirmationQueryL(class TDesC16 const &)
	?ConfirmationQueryL@MailUtils@@SAHABVTDesC16@@H@Z @ 18 NONAME ; int MailUtils::ConfirmationQueryL(class TDesC16 const &, int)
	?ConfirmationQueryL@MailUtils@@SAHH@Z @ 19 NONAME ; int MailUtils::ConfirmationQueryL(int)
	?ConfirmationQueryL@MailUtils@@SAHHH@Z @ 20 NONAME ; int MailUtils::ConfirmationQueryL(int, int)
	?ConstructL@CMsgMailAppUi@@MAEXXZ @ 21 NONAME ; void CMsgMailAppUi::ConstructL(void)
	?ConvertToCharsetL@CMailMessage@@QAEXI@Z @ 22 NONAME ; void CMailMessage::ConvertToCharsetL(unsigned int)
	?CreateForwardL@CMsgMailDocument@@MAEPAVCMsvOperation@@JIAAVTRequestStatus@@@Z @ 23 NONAME ; class CMsvOperation * CMsgMailDocument::CreateForwardL(long, unsigned int, class TRequestStatus &)
	?CreateNewL@CMsgMailDocument@@QAEJJJHVTUid@@@Z @ 24 NONAME ; long CMsgMailDocument::CreateNewL(long, long, int, class TUid)
	?CreateReplyL@CMsgMailDocument@@MAEPAVCMsvOperation@@JIAAVTRequestStatus@@@Z @ 25 NONAME ; class CMsvOperation * CMsgMailDocument::CreateReplyL(long, unsigned int, class TRequestStatus &)
	?CreateViewPluginsL@MailViewFactory@@SAPAV?$CArrayPtr@VCMailMessageView@@@@XZ @ 26 NONAME ; class CArrayPtr<class CMailMessageView> * MailViewFactory::CreateViewPluginsL(void)
	?DefaultAccountSettingsL@CMsgMailPreferences@@QAEXJAAVCMsvSession@@@Z @ 27 NONAME ; void CMsgMailPreferences::DefaultAccountSettingsL(long, class CMsvSession &)
	?EntryChangedL@CMsgMailDocument@@MAEXXZ @ 28 NONAME ; void CMsgMailDocument::EntryChangedL(void)
	?ExportSendOptionsL@CMsgMailPreferences@@QAEXABVTMsvEmailEntry@@@Z @ 29 NONAME ; void CMsgMailPreferences::ExportSendOptionsL(class TMsvEmailEntry const &)
	?FileSize@MailUtils@@SAHABVTDesC16@@@Z @ 30 NONAME ; int MailUtils::FileSize(class TDesC16 const &)
	?GetAdditionalHeaderVisibility@CMsgMailPreferences@@QAE?AW4EHeaderStatus@@W4TMsgControlId@@@Z @ 31 NONAME ; enum EHeaderStatus CMsgMailPreferences::GetAdditionalHeaderVisibility(enum TMsgControlId)
	?GetCRBinary@CMailCRHandler@@QBEHABVTUid@@KAAVTDes8@@@Z @ 32 NONAME ; int CMailCRHandler::GetCRBinary(class TUid const &, unsigned long, class TDes8 &) const
	?GetCRInt@CMailCRHandler@@QBEHABVTUid@@KAAH@Z @ 33 NONAME ; int CMailCRHandler::GetCRInt(class TUid const &, unsigned long, int &) const
	?GetCRReal@CMailCRHandler@@QBEHABVTUid@@KAAN@Z @ 34 NONAME ; int CMailCRHandler::GetCRReal(class TUid const &, unsigned long, double &) const
	?GetCRString@CMailCRHandler@@QBEHABVTUid@@KAAVTDes16@@@Z @ 35 NONAME ; int CMailCRHandler::GetCRString(class TUid const &, unsigned long, class TDes16 &) const
	?GetDRMDataTypeL@MsgMailDRMHandler@@QAE?AW4TDRMDataType@CMsgAttachmentInfo@@VRFile@@@Z @ 36 NONAME ; enum CMsgAttachmentInfo::TDRMDataType MsgMailDRMHandler::GetDRMDataTypeL(class RFile)
	?GetFileHandleL@CMailMessage@@QAE?AVRFile@@I@Z @ 37 NONAME ; class RFile CMailMessage::GetFileHandleL(unsigned int)
	?HtmlCharsetIdL@CMailMessage@@QAEIXZ @ 38 NONAME ; unsigned int CMailMessage::HtmlCharsetIdL(void)
	?ImportSendOptionsL@CMsgMailPreferences@@QAEXAAVTMsvEmailEntry@@@Z @ 39 NONAME ; void CMsgMailPreferences::ImportSendOptionsL(class TMsvEmailEntry &)
	?InformationNoteL@MailUtils@@SAXABVTDesC16@@@Z @ 40 NONAME ; void MailUtils::InformationNoteL(class TDesC16 const &)
	?InformationNoteL@MailUtils@@SAXH@Z @ 41 NONAME ; void MailUtils::InformationNoteL(int)
	?IsBannedMimeL@CMsgMailAppUi@@QBEHABVTDesC16@@@Z @ 42 NONAME ; int CMsgMailAppUi::IsBannedMimeL(class TDesC16 const &) const
	?IsClosedFileL@MailUtils@@SAHAAVRFile@@@Z @ 43 NONAME ; int MailUtils::IsClosedFileL(class RFile &)
	?IsClosedMimeL@MailUtils@@SAHABVTDesC16@@@Z @ 44 NONAME ; int MailUtils::IsClosedMimeL(class TDesC16 const &)
	?IsClosedMimeL@MailUtils@@SAHABVTDesC8@@@Z @ 45 NONAME ; int MailUtils::IsClosedMimeL(class TDesC8 const &)
	?IsForwardLockedFileL@MsgMailDRMHandler@@QAEHAAVRFile@@@Z @ 46 NONAME ; int MsgMailDRMHandler::IsForwardLockedFileL(class RFile &)
	?IsOutgoingL@MailMessageUtils@@SAHAAVCMailMessage@@@Z @ 47 NONAME ; int MailMessageUtils::IsOutgoingL(class CMailMessage &)
	?IsSuperDistributableFileL@MsgMailDRMHandler@@QAEHAAVRFile@@@Z @ 48 NONAME ; int MsgMailDRMHandler::IsSuperDistributableFileL(class RFile &)
	?IsSyncMLMail@CMsgMailDocument@@QAEHXZ @ 49 NONAME ; int CMsgMailDocument::IsSyncMLMail(void)
	?IsValidAddress@CMsgMailAppUi@@QBEHABVTDesC16@@@Z @ 50 NONAME ; int CMsgMailAppUi::IsValidAddress(class TDesC16 const &) const
	?LargeAttachmentQueryL@MailUtils@@SAHHH@Z @ 51 NONAME ; int MailUtils::LargeAttachmentQueryL(int, int)
	?LoadAttachedMessagesL@CMailMessage@@QAEXAAVMMessageLoadObserver@@@Z @ 52 NONAME ; void CMailMessage::LoadAttachedMessagesL(class MMessageLoadObserver &)
	?LoadAttachmentsL@CMailMessage@@QAEXAAVMMessageLoadObserver@@@Z @ 53 NONAME ; void CMailMessage::LoadAttachmentsL(class MMessageLoadObserver &)
	?LoadHtmlContentL@CMailMessage@@QAEXAAVMMessageLoadObserver@@@Z @ 54 NONAME ; void CMailMessage::LoadHtmlContentL(class MMessageLoadObserver &)
	?LoadLinkedHtmlContentL@CMailMessage@@QAEXABVTDesC16@@0@Z @ 55 NONAME ; void CMailMessage::LoadLinkedHtmlContentL(class TDesC16 const &, class TDesC16 const &)
	?LoadLinkedHtmlContentL@CMailMessage@@QAEXABVTDesC16@@0AAVMMessageLoadObserver@@@Z @ 56 NONAME ; void CMailMessage::LoadLinkedHtmlContentL(class TDesC16 const &, class TDesC16 const &, class MMessageLoadObserver &)
	?LoadMessageL@CMailMessage@@QAEXAAVMMessageLoadObserver@@@Z @ 57 NONAME ; void CMailMessage::LoadMessageL(class MMessageLoadObserver &)
	?MessageL@CMsgMailDocument@@QAEAAVCImEmailMessage@@XZ @ 58 NONAME ; class CImEmailMessage & CMsgMailDocument::MessageL(void)
	?MessageSizeL@CMsgMailAppUi@@IAEHH@Z @ 59 NONAME ; int CMsgMailAppUi::MessageSizeL(int)
	?MsgSaveL@CMsgMailAppUi@@QAEHHH@Z @ 60 NONAME ; int CMsgMailAppUi::MsgSaveL(int, int)
	?NewL@CMailCRHandler@@SAPAV1@PAVCMsgMailDocument@@@Z @ 61 NONAME ; class CMailCRHandler * CMailCRHandler::NewL(class CMsgMailDocument *)
	?NewL@CMailMessage@@SAPAV1@AAVCMsvEntry@@@Z @ 62 NONAME ; class CMailMessage * CMailMessage::NewL(class CMsvEntry &)
	?NewL@MsgMailDRMHandler@@SAPAV1@XZ @ 63 NONAME ; class MsgMailDRMHandler * MsgMailDRMHandler::NewL(void)
	?OfflineProfileActiveL@MailUtils@@SAHXZ @ 64 NONAME ; int MailUtils::OfflineProfileActiveL(void)
	?OfflineProfileActiveWithNoteL@MailUtils@@SAHXZ @ 65 NONAME ; int MailUtils::OfflineProfileActiveWithNoteL(void)
	?OverrideHtmlMessageCharset@CMailMessage@@QAEXI@Z @ 66 NONAME ; void CMailMessage::OverrideHtmlMessageCharset(unsigned int)
	?ResolveMimeType@CMsgMailDocument@@QAE?AVTDataType@@VRFile@@@Z @ 67 NONAME ; class TDataType CMsgMailDocument::ResolveMimeType(class RFile)
	?SetAdditionalHeaders@CMsgMailPreferences@@QAEXH@Z @ 68 NONAME ; void CMsgMailPreferences::SetAdditionalHeaders(int)
	?SetCRBinary@CMailCRHandler@@QBEHABVTUid@@KABVTDesC8@@@Z @ 69 NONAME ; int CMailCRHandler::SetCRBinary(class TUid const &, unsigned long, class TDesC8 const &) const
	?SetCRInt@CMailCRHandler@@QBEHABVTUid@@KH@Z @ 70 NONAME ; int CMailCRHandler::SetCRInt(class TUid const &, unsigned long, int) const
	?SetCRReal@CMailCRHandler@@QBEHABVTUid@@KABN@Z @ 71 NONAME ; int CMailCRHandler::SetCRReal(class TUid const &, unsigned long, double const &) const
	?SetCRString@CMailCRHandler@@QBEHABVTUid@@KABVTDesC16@@@Z @ 72 NONAME ; int CMailCRHandler::SetCRString(class TUid const &, unsigned long, class TDesC16 const &) const
	?SetDRMDataTypeL@MsgMailDRMHandler@@QAEXAAVCMsgAttachmentInfo@@AAVRFile@@@Z @ 73 NONAME ; void MsgMailDRMHandler::SetDRMDataTypeL(class CMsgAttachmentInfo &, class RFile &)
	?SetNotifyHandlerL@CMailCRHandler@@QAEXPAVMCenRepNotifyHandlerCallback@@W4ERepository@1@W4TCenRepKeyType@CCenRepNotifyHandler@@K@Z @ 74 NONAME ; void CMailCRHandler::SetNotifyHandlerL(class MCenRepNotifyHandlerCallback *, enum CMailCRHandler::ERepository, enum CCenRepNotifyHandler::TCenRepKeyType, unsigned long)
	?ShowNoteIfMsgStoreSpaceLowL@MailUtils@@SAHH@Z @ 75 NONAME ; int MailUtils::ShowNoteIfMsgStoreSpaceLowL(int)
	?TMsvEMailEntryL@CMsgMailDocument@@QAEABVTMsvEmailEntry@@XZ @ 76 NONAME ; class TMsvEmailEntry const & CMsgMailDocument::TMsvEMailEntryL(void)
	?TextQueryL@MailUtils@@SAXHAAVTDes16@@@Z @ 77 NONAME ; void MailUtils::TextQueryL(int, class TDes16 &)
	?UpdateModelFromCentralRepositoryL@CMailCRHandler@@QAEXXZ @ 78 NONAME ; void CMailCRHandler::UpdateModelFromCentralRepositoryL(void)
	?SetDialerEnabled@CMsgMailAppUi@@QAEXH@Z @ 79 NONAME ; void CMsgMailAppUi::SetDialerEnabled(int)

